@@ -4,7 +4,7 @@ AtteanX::Serializer::SPARQLXML - SPARQL Results XML Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::SPARQLXML version 0.026
+This document describes AtteanX::Serializer::SPARQLXML version 0.028
 
 =head1 SYNOPSIS
 
@@ -22,6 +22,8 @@ This document describes AtteanX::Serializer::SPARQLXML version 0.026
 
 =item C<< canonical_media_type >>
 
+=item C<< file_extensions >>
+
 =back
 
 =head1 METHODS
@@ -33,7 +35,7 @@ This document describes AtteanX::Serializer::SPARQLXML version 0.026
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::SPARQLXML 0.026 {
+package AtteanX::Serializer::SPARQLXML 0.028 {
 	use Moo;
 	use Types::Standard qw(Str ArrayRef);
 	use Encode qw(encode encode_utf8);
@@ -53,6 +55,14 @@ Returns a list of media types that identify the format produced by this serializ
 	sub media_types {
 		return [qw(application/sparql-results+xml)];
 	}
+
+=item C<< file_extensions >>
+
+Returns a list of file extensions associated with the serialized format.
+
+=cut
+
+	sub file_extensions { return [qw(srx xml)] };
 	
 =item C<< serialize_iter_to_io( $fh, $iterator ) >>
 
